==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/lb/data_lb_list_deleted/main.tf <==
/*
Пример использования
Получение списка удаленных load balancer (балансировщиков нагрузок)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_lb_list_deleted" "lbld" {
  #фильтр по id балансировщика нагрузки 
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени балансировщика нагрузки
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка балансировщиков нагрузки
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #фильтр по IP front
  #опциональный параметр
  #тип - строка
  #front_ip = "ENABLED"

  #фильтр по IP back
  #опциональный параметр
  #тип - строка
  #back_ip = "ENABLED"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.dynamix_lb_list_deleted.lbld
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/lb/data_lb_list_deleted/main.tf <==
/*
Пример использования
Получение списка удаленных load balancer (балансировщиков нагрузок)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_lb_list_deleted" "lbld" {
  #фильтр по id балансировщика нагрузки 
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени балансировщика нагрузки
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка балансировщиков нагрузки
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #фильтр по IP front
  #опциональный параметр
  #тип - строка
  #front_ip = "ENABLED"

  #фильтр по IP back
  #опциональный параметр
  #тип - строка
  #back_ip = "ENABLED"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.dynamix_lb_list_deleted.lbld
}
